@@ -1221,9 +1221,7 @@ void on_find_button_clicked(GtkAction *action, gpointer user_data)
 		ui->find_bar_is_visible = FALSE;
 	} else {
 		gtk_widget_show_all(GTK_WIDGET(ui->find_bar));
-		/* TODO: Select search string for overwriting and
-		 * set focus */
-		/*gtk_widget_grab_focus(GTK_WIDGET(ui->find_bar));*/
+		hildon_find_toolbar_highlight_entry(ui->find_bar, TRUE);
 		ui->find_bar_is_visible = TRUE;
 	}
 }
