@@ -33,8 +33,11 @@
 #include <hildon/hildon-text-view.h>
 #include <hildon/hildon-pannable-area.h>
 #include <hildon/hildon-gtk.h>
+#include <gdk/gdkx.h>
+#include <X11/Xatom.h>
 #endif
 
+#include "conboy_config.h"
 #include "callbacks.h"
 #include "metadata.h"
 #include "interface.h"
@@ -104,6 +107,7 @@ on_orientation_changed(GdkScreen *screen, GHashTable *hash)
 	GtkWidget *toolbar = g_hash_table_lookup(hash, "toolbar");
 	GtkWidget *menu_open = g_hash_table_lookup(hash, "menu_open");
 	GtkWidget *menu_settings = g_hash_table_lookup(hash, "menu_settings");
+	GtkTextView *text_view = g_hash_table_lookup(hash, "text_view");
 
 	app_data->portrait = is_portrait_mode();
 
@@ -111,10 +115,12 @@ on_orientation_changed(GdkScreen *screen, GHashTable *hash)
 		gtk_widget_hide(toolbar);
 		gtk_widget_hide(menu_settings);
 		gtk_widget_show(menu_open);
+		gtk_text_view_set_editable(text_view, FALSE);
 	} else {
 		gtk_widget_show(toolbar);
 		gtk_widget_show(menu_settings);
 		gtk_widget_hide(menu_open);
+		gtk_text_view_set_editable(text_view, TRUE);
 	}
 }
 
@@ -212,6 +218,93 @@ on_font_size_changed(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpoi
 	pango_font_description_free(font);
 }
 
+
+enum Icon {
+	ICON_DEC_INDENT,
+	ICON_INC_INDENT,
+	ICON_LINK,
+	ICON_TEXT_STYLE,
+	ICON_DELETE,
+	ICON_SEARCH,
+	ICON_OPEN
+};
+
+static GtkWidget*
+add_icon(const gchar *filename, GtkToolButton *button)
+{
+	/* If we don't find the icons in these two paths, we return the stock button */
+	gchar *full_path = g_build_filename(PREFIX, "/share/icons/hicolor/48x48/hildon", filename, NULL);
+	if (!g_file_test(full_path, G_FILE_TEST_EXISTS)) {
+		g_printerr("not found: %s\n", full_path);
+		g_free(full_path);
+		full_path = g_build_filename("/home/conny/workspace/conboy/data/icons/48x48", filename, NULL);
+		if (!g_file_test(full_path, G_FILE_TEST_EXISTS)) {
+			g_free(full_path);
+			return GTK_WIDGET(button);
+		}
+	}
+
+	/* If we found the icon, we set it and return the button with icon */
+	GtkWidget *icon = gtk_image_new_from_file(full_path);
+	gtk_widget_show(icon);
+	gtk_tool_button_set_icon_widget(button, icon);
+	g_free(full_path);
+	return GTK_WIDGET(button);
+}
+
+static GtkWidget*
+create_tool_button(GtkAction *action, enum Icon icon)
+{
+	GtkToolButton *button = GTK_TOOL_BUTTON(gtk_action_create_tool_item(action));
+
+#ifdef HILDON_HAS_APP_MENU
+	switch (icon)
+	{
+		case ICON_INC_INDENT:
+			return add_icon("conboy-increase_indent.png", button);
+
+		case ICON_DEC_INDENT:
+			return add_icon("conboy-decrease_indent.png", button);
+
+		case ICON_LINK:
+			return add_icon("conboy-hyperlink.png", button);
+
+		case ICON_TEXT_STYLE:
+			return add_icon("conboy-text_transform.png", button);
+
+		case ICON_SEARCH:
+			return add_icon("general_search.png", button);
+
+		case ICON_OPEN:
+			return add_icon("general_toolbar_folder.png", button);
+
+		case ICON_DELETE:
+			return add_icon("general_delete.png", button);
+
+		default:
+			return GTK_WIDGET(button);
+	}
+#else
+	return GTK_WIDGET(button);
+#endif
+}
+
+static void
+ungrab_volume_keys(GtkWidget *window)
+{
+	#ifdef HILDON_HAS_APP_MENU
+    /* Tell maemo-status-volume daemon to ungrab keys */
+    unsigned long val = 1; /* ungrab, use 0 to grab */
+    Atom atom;
+    GdkDisplay *display = NULL;
+    display = gdk_drawable_get_display (GDK_DRAWABLE(window->window));
+    atom = gdk_x11_get_xatom_by_name_for_display (display, "_HILDON_ZOOM_KEY_ATOM");
+    XChangeProperty (GDK_DISPLAY_XDISPLAY (display),
+                     GDK_WINDOW_XID (GDK_DRAWABLE(window->window)), atom, XA_INTEGER, 32,
+                     PropModeReplace, (unsigned char *) &val, 1);
+	#endif
+}
+
 /*
  * I'm not sure what is better:
  * 1) Declaring all as GtkWidget, so that Fremantle and Diablo code can share these.
@@ -294,6 +387,13 @@ GtkWidget* create_mainwin(Note *note) {
 	AppData *app_data = app_data_get();
 
 	mainwin = hildon_window_new();
+
+	/* Needs to be shown before ungrap_volumne_keys is called */
+	gtk_widget_show(mainwin);
+
+	/* Remap +/- keys */
+	ungrab_volume_keys(GTK_WIDGET(mainwin));
+
 	gtk_window_set_title(GTK_WINDOW(mainwin), "Conboy");
 
 	screen = gdk_screen_get_default();
@@ -409,7 +509,7 @@ GtkWidget* create_mainwin(Note *note) {
 	set_item_label(GTK_CONTAINER(menu_bold),       "<b>", _("Bold"), "</b>");
 	set_item_label(GTK_CONTAINER(menu_italic),     "<i>", _("Italic"), "</i>");
 	set_item_label(GTK_CONTAINER(menu_strike),     "<s>", _("Strikeout"), "</s>");
-	set_item_label(GTK_CONTAINER(menu_highlight),  "<span background=\"yellow\">", _("Highlight"), "</span>");
+	set_item_label(GTK_CONTAINER(menu_highlight),  "<span background=\"yellow\" foreground=\"black\">", _("Highlight"), "</span>");
 	set_item_label(GTK_CONTAINER(menu_fixed),      "<tt>", _("Fixed Width"), "</tt>");
 	set_item_label(GTK_CONTAINER(menu_font_small), "<span size=\"small\">", _("Small"), "</span>");
 	set_item_label(GTK_CONTAINER(menu_font_large), "<span size=\"large\">", _("Large"), "</span>");
@@ -524,7 +624,7 @@ GtkWidget* create_mainwin(Note *note) {
 	toolbar = gtk_toolbar_new();
 
 	/****/
-	button_dec_indent = gtk_action_create_tool_item(action_dec_indent);
+	button_dec_indent = create_tool_button(action_dec_indent, ICON_DEC_INDENT);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_dec_indent), -1);
 #ifdef HILDON_HAS_APP_MENU
 	gtk_widget_set_size_request(GTK_WIDGET(button_dec_indent), 105, -1);
@@ -532,30 +632,30 @@ GtkWidget* create_mainwin(Note *note) {
 	gtk_widget_set_size_request(GTK_WIDGET(button_dec_indent), 85, -1);
 #endif
 
-	button_inc_indent = gtk_action_create_tool_item(action_inc_indent);
+	button_inc_indent = create_tool_button(action_inc_indent, ICON_INC_INDENT);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_inc_indent), -1);
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
-	button_link = gtk_action_create_tool_item(action_link);
+	button_link = create_tool_button(action_link, ICON_LINK);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_link), -1);
 
-	button_style = gtk_action_create_tool_item(action_text_style);
+	button_style = create_tool_button(action_text_style, ICON_TEXT_STYLE);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_style), -1);
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
-	button_find = gtk_action_create_tool_item(action_find);
+	button_find = create_tool_button(action_find, ICON_SEARCH);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_find), -1);
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
-	button_delete = gtk_action_create_tool_item(action_delete);
+	button_delete = create_tool_button(action_delete, ICON_DELETE);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_delete), -1);
 
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
 
-	button_notes = gtk_action_create_tool_item(action_notes);
+	button_notes = create_tool_button(action_notes, ICON_OPEN);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button_notes), -1);
 
 	gtk_widget_show_all(toolbar);
@@ -810,6 +910,7 @@ GtkWidget* create_mainwin(Note *note) {
 	g_hash_table_insert(hash, "menu_new", menu_new);
 	g_hash_table_insert(hash, "menu_open", menu_open);
 	g_hash_table_insert(hash, "menu_settings", menu_settings);
+	g_hash_table_insert(hash, "text_view", textview);
 	g_signal_connect((gpointer)screen, "size-changed",
 			G_CALLBACK(on_orientation_changed),
 			hash);
