@@ -255,7 +255,9 @@ void note_close_window(Note *note)
 	}
 }
 
-
+/**
+ * Deletes the note from the filesystem but does not free it from memory.
+ */
 void note_delete(Note *note)
 {
 	AppData *app_data = app_data_get();
@@ -264,18 +266,9 @@ void note_delete(Note *note)
 	if (!storage_delete_note(note->guid)) {
 		g_printerr("ERROR: The note with the guid %s could not be deleted \n", note->guid);
 	}
-		
-	/*
-	if (g_unlink(note->filename) == -1) {
-		g_printerr("ERROR: The file %s could not be deleted \n", note->filename);
-	}
-	*/
 
 	/* Remove from list store */
 	note_list_store_remove(app_data->note_store, note);
-
-	/* Free memory */
-	/*note_free(note);*/
 }
 
 
